@@ -147,16 +147,22 @@ def valid_collect_keys(ctx):
 @click.option('--monitor', is_flag=True,
               help='Flag to monitor pipeline jobs continuously. '
               'Default is not to monitor (kick off jobs and exit).')
+@click.option('--background', is_flag=True,
+              help='Flag to monitor pipeline jobs continuously '
+              'in the background using the nohup command. Note that the '
+              'stdout/stderr will not be captured, but you can set a '
+              'pipeline "log_file" to capture logs.')
 @click.option('-v', '--verbose', is_flag=True,
               help='Flag to turn on debug logging.')
 @click.pass_context
-def pipeline(ctx, cancel, monitor, verbose):
+def pipeline(ctx, cancel, monitor, background, verbose):
     """Execute multiple steps in a reV analysis pipeline."""
     if ctx.invoked_subcommand is None:
         config_file = ctx.obj['CONFIG_FILE']
         verbose = any([verbose, ctx.obj['VERBOSE']])
         ctx.invoke(run_pipeline_from_config, config_file=config_file,
-                   cancel=cancel, monitor=monitor, verbose=verbose)
+                   cancel=cancel, monitor=monitor, background=background,
+                   verbose=verbose)
 
 
 @pipeline.command()
@@ -173,16 +179,23 @@ def valid_pipeline_keys(ctx):
               help='Flag to do a dry run (make batch dirs without running).')
 @click.option('--cancel', is_flag=True,
               help='Flag to cancel all jobs associated with a given batch.')
+@click.option('--monitor-background', is_flag=True,
+              help='Flag to monitor all batch pipelines continuously '
+              'in the background using the nohup command. Note that the '
+              'stdout/stderr will not be captured, but you can set a '
+              'pipeline "log_file" to capture logs.')
 @click.option('-v', '--verbose', is_flag=True,
               help='Flag to turn on debug logging.')
 @click.pass_context
-def batch(ctx, dry_run, cancel, verbose):
+def batch(ctx, dry_run, cancel, monitor_background, verbose):
     """Execute multiple steps in a reV analysis pipeline."""
     if ctx.invoked_subcommand is None:
         config_file = ctx.obj['CONFIG_FILE']
         verbose = any([verbose, ctx.obj['VERBOSE']])
         ctx.invoke(run_batch_from_config, config_file=config_file,
-                   dry_run=dry_run, cancel=cancel, verbose=verbose)
+                   dry_run=dry_run, cancel=cancel,
+                   monitor_background=monitor_background,
+                   verbose=verbose)
 
 
 @batch.command()
