@@ -47,9 +47,6 @@ class BaseConfig(dict):
         if check_keys:
             self._check_keys()
 
-    def __repr__(self):
-        return self.__class__.__name__
-
     @property
     def config_dir(self):
         """Get the directory that the config file is in.
@@ -125,7 +122,8 @@ class BaseConfig(dict):
                 missing.append(req)
 
         if any(missing):
-            e = '{} missing the following keys: {}'.format(self, missing)
+            e = ('{} missing the following keys: {}'
+                 .format(self.__class__.__name__, missing))
             logger.error(e)
             raise ConfigError(e)
 
@@ -151,7 +149,7 @@ class BaseConfig(dict):
         for key, value in self.items():
             if isinstance(value, str) and key not in self._keys:
                 msg = ('{} is not a valid config entry for {}! Must be one of:'
-                       '\n{}'.format(key, self, self._keys))
+                       '\n{}'.format(key, self.__class__.__name__, self._keys))
                 logger.error(msg)
                 raise ConfigError(msg)
 
